@@ -34,7 +34,8 @@ def tagExpressionGen(argstr):
 
 def run() :
     parser = argparse.ArgumentParser()
-    parser.add_argument('--version', action='version', version=f'hytest v{version}')
+    parser.add_argument('--version', action='version', version=f'hytest v{version}',help="显示版本号" )
+    parser.add_argument('--new',  metavar='project_dir', help="创建新项目目录" )
     parser.add_argument("case_dir", help="用例根目录", nargs='?', default='cases')
     parser.add_argument("-L", "--loglevel", metavar='Level_Number', type=int, help="日志级别  0:低 - 1:高", default=0)
 
@@ -52,6 +53,23 @@ def run() :
         print(fileArgs)
         args = parser.parse_args(fileArgs,args)
 
+    # 创建项目目录
+    if args.new:
+        projDir =  args.new
+        if os.path.exists(projDir):
+            print(f'{projDir} already exists！')
+            exit(2)
+        os.makedirs(f'{projDir}/cases')
+        with open(f'{projDir}/cases/case1.py','w',encoding='utf8') as f:
+            f.write('''class c1:
+    name = '用例名称 - 0001'
+
+    # 测试用例步骤
+    def teststeps(self):...''')
+
+        exit()
+
+
     LogLevel.level = args.loglevel
     # print('loglevel',LogLevel.level)
 
